==> huaweicloudsdkcce-3.1.46-py2.py3-none-any.whl: huaweicloudsdkcce/v3/model/node_pool_spec.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class NodePoolSpec:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'type': 'str',
        'node_template': 'NodeSpec',
        'initial_node_count': 'int',
        'autoscaling': 'NodePoolNodeAutoscaling',
        'node_management': 'NodeManagement',
        'pod_security_groups': 'list[SecurityID]',
        'custom_security_groups': 'list[str]'
    }

    attribute_map = {
        'type': 'type',
        'node_template': 'nodeTemplate',
        'initial_node_count': 'initialNodeCount',
        'autoscaling': 'autoscaling',
        'node_management': 'nodeManagement',
        'pod_security_groups': 'podSecurityGroups',
        'custom_security_groups': 'customSecurityGroups'
    }

    def __init__(self, type=None, node_template=None, initial_node_count=None, autoscaling=None, node_management=None, pod_security_groups=None, custom_security_groups=None):
        """NodePoolSpec

        The model defined in huaweicloud sdk

        :param type: 节点池类型。不填写时默认为vm。  - vm：弹性云服务器 - ElasticBMS：C6型弹性裸金属通用计算增强型云服务器，规格示例：c6.22xlarge.2.physical - pm: 裸金属服务器 
        :type type: str
        :param node_template: 
        :type node_template: :class:`huaweicloudsdkcce.v3.NodeSpec`
        :param initial_node_count: 节点池初始化节点个数。查询时为节点池目标节点数量。
        :type initial_node_count: int
        :param autoscaling: 
        :type autoscaling: :class:`huaweicloudsdkcce.v3.NodePoolNodeAutoscaling`
        :param node_management: 
        :type node_management: :class:`huaweicloudsdkcce.v3.NodeManagement`
        :param pod_security_groups: 1.21版本集群节点池支持绑定安全组，最多五个。
        :type pod_security_groups: list[:class:`huaweicloudsdkcce.v3.SecurityID`]
        :param custom_security_groups: 节点池自定义安全组相关配置。支持节点池新扩容节点绑定指定的安全组。  - 未指定安全组ID，新建节点将添加Node节点默认安全组。  - 指定有效安全组ID，新建节点将使用指定安全组。  - 指定安全组，应避免对CCE运行依赖的端口规则进行修改。[详细设置请参考[集群安全组规则配置](https://support.huaweicloud.com/cce_faq/cce_faq_00265.html)。](tag:hws)[详细设置请参考[集群安全组规则配置](https://support.huaweicloud.com/intl/zh-cn/cce_faq/cce_faq_00265.html)。](tag:hws_hk) 
        :type custom_security_groups: list[str]
        """
        
        

        self._type = None
        self._node_template = None
        self._initial_node_count = None
        self._autoscaling = None
        self._node_management = None
        self._pod_security_groups = None
        self._custom_security_groups = None
        self.discriminator = None

        if type is not None:
            self.type = type
        self.node_template = node_template
        if initial_node_count is not None:
            self.initial_node_count = initial_node_count
        if autoscaling is not None:
            self.autoscaling = autoscaling
        if node_management is not None:
            self.node_management = node_management
        if pod_security_groups is not None:
            self.pod_security_groups = pod_security_groups
        if custom_security_groups is not None:
            self.custom_security_groups = custom_security_groups

    @property
    def type(self):
        """Gets the type of this NodePoolSpec.

        节点池类型。不填写时默认为vm。  - vm：弹性云服务器 - ElasticBMS：C6型弹性裸金属通用计算增强型云服务器，规格示例：c6.22xlarge.2.physical - pm: 裸金属服务器 

        :return: The type of this NodePoolSpec.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this NodePoolSpec.

        节点池类型。不填写时默认为vm。  - vm：弹性云服务器 - ElasticBMS：C6型弹性裸金属通用计算增强型云服务器，规格示例：c6.22xlarge.2.physical - pm: 裸金属服务器 

        :param type: The type of this NodePoolSpec.
        :type type: str
        """
        self._type = type

    @property
    def node_template(self):
        """Gets the node_template of this NodePoolSpec.

        :return: The node_template of this NodePoolSpec.
        :rtype: :class:`huaweicloudsdkcce.v3.NodeSpec`
        """
        return self._node_template

    @node_template.setter
    def node_template(self, node_template):
        """Sets the node_template of this NodePoolSpec.

        :param node_template: The node_template of this NodePoolSpec.
        :type node_template: :class:`huaweicloudsdkcce.v3.NodeSpec`
        """
        self._node_template = node_template

    @property
    def initial_node_count(self):
        """Gets the initial_node_count of this NodePoolSpec.

        节点池初始化节点个数。查询时为节点池目标节点数量。

        :return: The initial_node_count of this NodePoolSpec.
        :rtype: int
        """
        return self._initial_node_count

    @initial_node_count.setter
    def initial_node_count(self, initial_node_count):
        """Sets the initial_node_count of this NodePoolSpec.

        节点池初始化节点个数。查询时为节点池目标节点数量。

        :param initial_node_count: The initial_node_count of this NodePoolSpec.
        :type initial_node_count: int
        """
        self._initial_node_count = initial_node_count

    @property
    def autoscaling(self):
        """Gets the autoscaling of this NodePoolSpec.

        :return: The autoscaling of this NodePoolSpec.
        :rtype: :class:`huaweicloudsdkcce.v3.NodePoolNodeAutoscaling`
        """
        return self._autoscaling

    @autoscaling.setter
    def autoscaling(self, autoscaling):
        """Sets the autoscaling of this NodePoolSpec.

        :param autoscaling: The autoscaling of this NodePoolSpec.
        :type autoscaling: :class:`huaweicloudsdkcce.v3.NodePoolNodeAutoscaling`
        """
        self._autoscaling = autoscaling

    @property
    def node_management(self):
        """Gets the node_management of this NodePoolSpec.

        :return: The node_management of this NodePoolSpec.
        :rtype: :class:`huaweicloudsdkcce.v3.NodeManagement`
        """
        return self._node_management

    @node_management.setter
    def node_management(self, node_management):
        """Sets the node_management of this NodePoolSpec.

        :param node_management: The node_management of this NodePoolSpec.
        :type node_management: :class:`huaweicloudsdkcce.v3.NodeManagement`
        """
        self._node_management = node_management

    @property
    def pod_security_groups(self):
        """Gets the pod_security_groups of this NodePoolSpec.

        1.21版本集群节点池支持绑定安全组，最多五个。

        :return: The pod_security_groups of this NodePoolSpec.
        :rtype: list[:class:`huaweicloudsdkcce.v3.SecurityID`]
        """
        return self._pod_security_groups

    @pod_security_groups.setter
    def pod_security_groups(self, pod_security_groups):
        """Sets the pod_security_groups of this NodePoolSpec.

        1.21版本集群节点池支持绑定安全组，最多五个。

        :param pod_security_groups: The pod_security_groups of this NodePoolSpec.
        :type pod_security_groups: list[:class:`huaweicloudsdkcce.v3.SecurityID`]
        """
        self._pod_security_groups = pod_security_groups

    @property
    def custom_security_groups(self):
        """Gets the custom_security_groups of this NodePoolSpec.

        节点池自定义安全组相关配置。支持节点池新扩容节点绑定指定的安全组。  - 未指定安全组ID，新建节点将添加Node节点默认安全组。  - 指定有效安全组ID，新建节点将使用指定安全组。  - 指定安全组，应避免对CCE运行依赖的端口规则进行修改。[详细设置请参考[集群安全组规则配置](https://support.huaweicloud.com/cce_faq/cce_faq_00265.html)。](tag:hws)[详细设置请参考[集群安全组规则配置](https://support.huaweicloud.com/intl/zh-cn/cce_faq/cce_faq_00265.html)。](tag:hws_hk) 

        :return: The custom_security_groups of this NodePoolSpec.
        :rtype: list[str]
        """
        return self._custom_security_groups

    @custom_security_groups.setter
    def custom_security_groups(self, custom_security_groups):
        """Sets the custom_security_groups of this NodePoolSpec.

        节点池自定义安全组相关配置。支持节点池新扩容节点绑定指定的安全组。  - 未指定安全组ID，新建节点将添加Node节点默认安全组。  - 指定有效安全组ID，新建节点将使用指定安全组。  - 指定安全组，应避免对CCE运行依赖的端口规则进行修改。[详细设置请参考[集群安全组规则配置](https://support.huaweicloud.com/cce_faq/cce_faq_00265.html)。](tag:hws)[详细设置请参考[集群安全组规则配置](https://support.huaweicloud.com/intl/zh-cn/cce_faq/cce_faq_00265.html)。](tag:hws_hk) 

        :param custom_security_groups: The custom_security_groups of this NodePoolSpec.
        :type custom_security_groups: list[str]
        """
        self._custom_security_groups = custom_security_groups

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NodePoolSpec):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcce-3.1.105-py2.py3-none-any.whl: huaweicloudsdkcce/v3/model/node_pool_spec.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class NodePoolSpec:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'type': 'str',
        'node_template': 'NodeSpec',
        'initial_node_count': 'int',
        'autoscaling': 'NodePoolNodeAutoscaling',
        'node_management': 'NodeManagement',
        'pod_security_groups': 'list[SecurityID]',
        'extension_scale_groups': 'ExtensionScaleGroup',
        'custom_security_groups': 'list[str]'
    }

    attribute_map = {
        'type': 'type',
        'node_template': 'nodeTemplate',
        'initial_node_count': 'initialNodeCount',
        'autoscaling': 'autoscaling',
        'node_management': 'nodeManagement',
        'pod_security_groups': 'podSecurityGroups',
        'extension_scale_groups': 'extensionScaleGroups',
        'custom_security_groups': 'customSecurityGroups'
    }

    def __init__(self, type=None, node_template=None, initial_node_count=None, autoscaling=None, node_management=None, pod_security_groups=None, extension_scale_groups=None, custom_security_groups=None):
        """NodePoolSpec

        The model defined in huaweicloud sdk

        :param type: 节点池类型。不填写时默认为vm。  - vm：弹性云服务器 - ElasticBMS：C6型弹性裸金属通用计算增强型云服务器，规格示例：c6.22xlarge.2.physical - pm: 裸金属服务器 
        :type type: str
        :param node_template: 
        :type node_template: :class:`huaweicloudsdkcce.v3.NodeSpec`
        :param initial_node_count: 节点池初始化节点个数。查询时为节点池目标节点数量。
        :type initial_node_count: int
        :param autoscaling: 
        :type autoscaling: :class:`huaweicloudsdkcce.v3.NodePoolNodeAutoscaling`
        :param node_management: 
        :type node_management: :class:`huaweicloudsdkcce.v3.NodeManagement`
        :param pod_security_groups: 1.21版本集群节点池支持绑定安全组，最多五个。
        :type pod_security_groups: list[:class:`huaweicloudsdkcce.v3.SecurityID`]
        :param extension_scale_groups: 
        :type extension_scale_groups: :class:`huaweicloudsdkcce.v3.ExtensionScaleGroup`
        :param custom_security_groups: 节点池自定义安全组相关配置。支持节点池新扩容节点绑定指定的安全组。  - 未指定安全组ID，新建节点将添加Node节点默认安全组。  - 指定有效安全组ID，新建节点将使用指定安全组。  - 指定安全组，应避免对CCE运行依赖的端口规则进行修改。[详细设置请参考[集群安全组规则配置](https://support.huaweicloud.com/cce_faq/cce_faq_00265.html)。](tag:hws)[详细设置请参考[集群安全组规则配置](https://support.huaweicloud.com/intl/zh-cn/cce_faq/cce_faq_00265.html)。](tag:hws_hk) 
        :type custom_security_groups: list[str]
        """
        
        

        self._type = None
        self._node_template = None
        self._initial_node_count = None
        self._autoscaling = None
        self._node_management = None
        self._pod_security_groups = None
        self._extension_scale_groups = None
        self._custom_security_groups = None
        self.discriminator = None

        if type is not None:
            self.type = type
        self.node_template = node_template
        if initial_node_count is not None:
            self.initial_node_count = initial_node_count
        if autoscaling is not None:
            self.autoscaling = autoscaling
        if node_management is not None:
            self.node_management = node_management
        if pod_security_groups is not None:
            self.pod_security_groups = pod_security_groups
        if extension_scale_groups is not None:
            self.extension_scale_groups = extension_scale_groups
        if custom_security_groups is not None:
            self.custom_security_groups = custom_security_groups

    @property
    def type(self):
        """Gets the type of this NodePoolSpec.

        节点池类型。不填写时默认为vm。  - vm：弹性云服务器 - ElasticBMS：C6型弹性裸金属通用计算增强型云服务器，规格示例：c6.22xlarge.2.physical - pm: 裸金属服务器 

        :return: The type of this NodePoolSpec.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this NodePoolSpec.

        节点池类型。不填写时默认为vm。  - vm：弹性云服务器 - ElasticBMS：C6型弹性裸金属通用计算增强型云服务器，规格示例：c6.22xlarge.2.physical - pm: 裸金属服务器 

        :param type: The type of this NodePoolSpec.
        :type type: str
        """
        self._type = type

    @property
    def node_template(self):
        """Gets the node_template of this NodePoolSpec.

        :return: The node_template of this NodePoolSpec.
        :rtype: :class:`huaweicloudsdkcce.v3.NodeSpec`
        """
        return self._node_template

    @node_template.setter
    def node_template(self, node_template):
        """Sets the node_template of this NodePoolSpec.

        :param node_template: The node_template of this NodePoolSpec.
        :type node_template: :class:`huaweicloudsdkcce.v3.NodeSpec`
        """
        self._node_template = node_template

    @property
    def initial_node_count(self):
        """Gets the initial_node_count of this NodePoolSpec.

        节点池初始化节点个数。查询时为节点池目标节点数量。

        :return: The initial_node_count of this NodePoolSpec.
        :rtype: int
        """
        return self._initial_node_count

    @initial_node_count.setter
    def initial_node_count(self, initial_node_count):
        """Sets the initial_node_count of this NodePoolSpec.

        节点池初始化节点个数。查询时为节点池目标节点数量。

        :param initial_node_count: The initial_node_count of this NodePoolSpec.
        :type initial_node_count: int
        """
        self._initial_node_count = initial_node_count

    @property
    def autoscaling(self):
        """Gets the autoscaling of this NodePoolSpec.

        :return: The autoscaling of this NodePoolSpec.
        :rtype: :class:`huaweicloudsdkcce.v3.NodePoolNodeAutoscaling`
        """
        return self._autoscaling

    @autoscaling.setter
    def autoscaling(self, autoscaling):
        """Sets the autoscaling of this NodePoolSpec.

        :param autoscaling: The autoscaling of this NodePoolSpec.
        :type autoscaling: :class:`huaweicloudsdkcce.v3.NodePoolNodeAutoscaling`
        """
        self._autoscaling = autoscaling

    @property
    def node_management(self):
        """Gets the node_management of this NodePoolSpec.

        :return: The node_management of this NodePoolSpec.
        :rtype: :class:`huaweicloudsdkcce.v3.NodeManagement`
        """
        return self._node_management

    @node_management.setter
    def node_management(self, node_management):
        """Sets the node_management of this NodePoolSpec.

        :param node_management: The node_management of this NodePoolSpec.
        :type node_management: :class:`huaweicloudsdkcce.v3.NodeManagement`
        """
        self._node_management = node_management

    @property
    def pod_security_groups(self):
        """Gets the pod_security_groups of this NodePoolSpec.

        1.21版本集群节点池支持绑定安全组，最多五个。

        :return: The pod_security_groups of this NodePoolSpec.
        :rtype: list[:class:`huaweicloudsdkcce.v3.SecurityID`]
        """
        return self._pod_security_groups

    @pod_security_groups.setter
    def pod_security_groups(self, pod_security_groups):
        """Sets the pod_security_groups of this NodePoolSpec.

        1.21版本集群节点池支持绑定安全组，最多五个。

        :param pod_security_groups: The pod_security_groups of this NodePoolSpec.
        :type pod_security_groups: list[:class:`huaweicloudsdkcce.v3.SecurityID`]
        """
        self._pod_security_groups = pod_security_groups

    @property
    def extension_scale_groups(self):
        """Gets the extension_scale_groups of this NodePoolSpec.

        :return: The extension_scale_groups of this NodePoolSpec.
        :rtype: :class:`huaweicloudsdkcce.v3.ExtensionScaleGroup`
        """
        return self._extension_scale_groups

    @extension_scale_groups.setter
    def extension_scale_groups(self, extension_scale_groups):
        """Sets the extension_scale_groups of this NodePoolSpec.

        :param extension_scale_groups: The extension_scale_groups of this NodePoolSpec.
        :type extension_scale_groups: :class:`huaweicloudsdkcce.v3.ExtensionScaleGroup`
        """
        self._extension_scale_groups = extension_scale_groups

    @property
    def custom_security_groups(self):
        """Gets the custom_security_groups of this NodePoolSpec.

        节点池自定义安全组相关配置。支持节点池新扩容节点绑定指定的安全组。  - 未指定安全组ID，新建节点将添加Node节点默认安全组。  - 指定有效安全组ID，新建节点将使用指定安全组。  - 指定安全组，应避免对CCE运行依赖的端口规则进行修改。[详细设置请参考[集群安全组规则配置](https://support.huaweicloud.com/cce_faq/cce_faq_00265.html)。](tag:hws)[详细设置请参考[集群安全组规则配置](https://support.huaweicloud.com/intl/zh-cn/cce_faq/cce_faq_00265.html)。](tag:hws_hk) 

        :return: The custom_security_groups of this NodePoolSpec.
        :rtype: list[str]
        """
        return self._custom_security_groups

    @custom_security_groups.setter
    def custom_security_groups(self, custom_security_groups):
        """Sets the custom_security_groups of this NodePoolSpec.

        节点池自定义安全组相关配置。支持节点池新扩容节点绑定指定的安全组。  - 未指定安全组ID，新建节点将添加Node节点默认安全组。  - 指定有效安全组ID，新建节点将使用指定安全组。  - 指定安全组，应避免对CCE运行依赖的端口规则进行修改。[详细设置请参考[集群安全组规则配置](https://support.huaweicloud.com/cce_faq/cce_faq_00265.html)。](tag:hws)[详细设置请参考[集群安全组规则配置](https://support.huaweicloud.com/intl/zh-cn/cce_faq/cce_faq_00265.html)。](tag:hws_hk) 

        :param custom_security_groups: The custom_security_groups of this NodePoolSpec.
        :type custom_security_groups: list[str]
        """
        self._custom_security_groups = custom_security_groups

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NodePoolSpec):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
